#!/usr/local/bin/php
<?php
/**
 * $Horde: whups/scripts/mail-filter.php,v 1.18 2005/09/16 21:26:13 ben Exp $
 *
 * This script accepts a MIME message on standard input and creates a
 * new ticket from its contents.
 */

@define('AUTH_HANDLER', true);
@define('HORDE_BASE', dirname(__FILE__) . '/../..');

// Do CLI checks and environment setup first.
require_once HORDE_BASE . '/lib/core.php';
require_once 'Horde/CLI.php';

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment - make sure there's no time limit, init
// some variables, etc.
Horde_CLI::init();
$cli = &Horde_CLI::singleton();

@define('WHUPS_BASE', HORDE_BASE . '/whups');
require_once WHUPS_BASE . '/lib/base.php';
require_once WHUPS_BASE . '/lib/Mail.php';
require_once WHUPS_BASE . '/lib/Ticket.php';
require_once 'Console/Getopt.php';

// Set server name.
$_SERVER['SERVER_NAME'] = $conf['mail']['server_name'];
$_SERVER['SERVER_PORT'] = $conf['mail']['server_port'];

// We accept the user name on the command-line.
$info = array();
$options = Console_Getopt::getopt(Console_Getopt::readPHPArgv(), 'a:q:Q:k:t:T:p:P:s:S:',
                                  array('queue=', 'queue-id=',
                                        'type=', 'type-id=',
                                        'priority=', 'priority-id=',
                                        'state=', 'state-id=',
                                        'ticket=', 'default-auth='));
if (is_a($options, 'PEAR_Error')) {
    // FIXME: We should bounce the message.
    exit(1);
}

list($opts, $args) = $options;
foreach ($opts as $opt) {
    list($optName, $optValue) = $opt;
    switch ($optName) {
    case 'a':
    case '--default-auth':
        $info['default_auth'] = $optDefaultAuth;
    	break;

    case 'k':
    case '--ticket':
        $info['ticket'] = (int)$optValue;
        break;

    case 'q':
    case '--queue':
        $queues = $whups->getQueues();
        foreach ($queues as $queueId => $queueName) {
            if (strcasecmp($queueName, $optValue) == 0) {
                $info['queue'] = $queueId;
                break;
            }
        }
        break;

    case 'Q':
    case '--queue-id':
        $queues = $whups->getQueues();
        foreach ($queues as $queueId => $queueName) {
            if (strcasecmp($queueId, $optValue) == 0) {
                $info['queue'] = $queueId;
                break;
            }
        }
        break;

    case 't':
    case '--type':
        $types = $whups->getTypes($info['queue']);
        foreach ($types as $typeId => $typeName) {
            if (strcasecmp($typeName, $optValue) == 0) {
                $info['type'] = $typeId;
                break;
            }
        }
        break;

    case 'T':
    case '--type-id':
        $types = $whups->getTypes($info['queue']);
        foreach ($types as $typeId => $typeName) {
            if (strcasecmp($typeId, $optValue) == 0) {
                $info['type'] = $typeId;
                break;
            }
        }
        break;

    case 'p':
    case '--priority':
        $priorities = $whups->getPriorities($info['type']);
        foreach ($priorities as $priorityId => $priorityName) {
            if (strcasecmp($priorityName, $optValue) == 0) {
                $info['priority'] = $priorityId;
                break;
            }
        }
        break;

    case 'P':
    case '--priority-id':
        $priorities = $whups->getPriorities($info['type']);
        foreach ($priorities as $priorityId => $priorityName) {
            if (strcasecmp($priorityId, $optValue) == 0) {
                $info['priority'] = $priorityId;
                break;
            }
        }
        break;

    case 's':
    case '--state':
        $states = $whups->getStates($info['type']);
        foreach ($states as $stateId => $stateName) {
            if (strcasecmp($stateName, $optValue) == 0) {
                $info['state'] = $stateId;
                break;
            }
        }
        break;

    case 'S':
    case '--state-id':
        $states = $whups->getStates($info['type']);
        foreach ($states as $stateId => $stateName) {
            if (strcasecmp($stateId, $optValue) == 0) {
                $info['state'] = $stateId;
                break;
            }
        }
        break;
    }
}

if (empty($info['ticket'])) {
    if (empty($info['queue'])) {
        $cli->fatal(_("--queue or --queue-id must specify a valid Queue."));
    }
    if (empty($info['type'])) {
        $cli->fatal(_("--type or --type-id must specify a valid Type."));
    }
    if (empty($info['priority'])) {
        $cli->fatal(_("--priority or --priority-id must specify a valid Priority."));
    }
    if (empty($info['state'])) {
        $cli->fatal(_("--state or --state-id must specify a valid State."));
    }
}

// Read and parse the message.
$text = '';
while (!feof(STDIN)) {
    $text .= fgets(STDIN, 512);
}

$result = Whups_Mail::processMail($text, $info);
if (is_a($result, 'PEAR_Error')) {
    $cli->fatal(sprintf(_("error processing message: %s"), $result->getMessage()));
    exit(1);
}

exit(0);
